Class: Airwallex::BillingCustomer
- Inherits:
-
APIResource
- Object
- APIResource
- Airwallex::BillingCustomer
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::Retrieve
- Includes:
- APIOperations::Update
- Defined in:
- lib/airwallex/resources/billing_customer.rb
Overview
Represents a Billing customer — the entity a BillingSubscription is scoped to. Distinct from Airwallex::Customer, which belongs to Payment Acceptance (/api/v1/pa/customers), not Billing.
Instance Attribute Summary
Attributes inherited from APIResource
Class Method Summary collapse
-
.resource_path ⇒ String
API resource path for billing customers.
Instance Method Summary collapse
-
#bank_transfer_instructions ⇒ Hash
Retrieve the bank transfer instructions for funding this customer's subscriptions (e.g. for a BT-funded instalment plan).
Methods included from APIOperations::Create
Methods included from APIOperations::Retrieve
Methods included from APIOperations::List
Methods included from APIOperations::Update
Methods inherited from APIResource
#changed_attributes, #dirty?, #initialize, #inspect, #method_missing, #refresh, #refresh_from, resource_name, #respond_to_missing?, #to_hash, #to_json, #to_s
Constructor Details
This class inherits a constructor from Airwallex::APIResource
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Airwallex::APIResource
Class Method Details
.resource_path ⇒ String
Returns API resource path for billing customers.
36 37 38 |
# File 'lib/airwallex/resources/billing_customer.rb', line 36 def self.resource_path "/api/v1/billing/billing_customers" end |
Instance Method Details
#bank_transfer_instructions ⇒ Hash
Retrieve the bank transfer instructions for funding this customer's subscriptions (e.g. for a BT-funded instalment plan).
44 45 46 |
# File 'lib/airwallex/resources/billing_customer.rb', line 44 def bank_transfer_instructions Airwallex.client.get("#{self.class.resource_path}/#{id}/bank_transfer_instructions") end |